ByteArkPlayerAdsData class
Constructors
- ByteArkPlayerAdsData({String? adId, String? adSystem, String? advertiserName, String? creativeAdId, String? creativeId, String? title})
-
ByteArkPlayerAdsData.fromMap(Map<
String, dynamic> map) -
factory
Properties
- adId → String?
-
final
- adSystem → String?
-
final
- advertiserName → String?
-
final
- creativeAdId → String?
-
final
- creativeId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited