ByteArkPlayerSubtitleSize enum

Enum representing subtitle size as a percentage of the video height.

Inheritance
Available extensions

Values

minimum → const ByteArkPlayerSubtitleSize

Minimum subtitle size (1% of video height)

extraTiny → const ByteArkPlayerSubtitleSize

Extra tiny subtitle size (2% of video height)

tiny → const ByteArkPlayerSubtitleSize

Tiny subtitle size (3% of video height)

extraSmall → const ByteArkPlayerSubtitleSize

Extra small subtitle size (4% of video height)

small → const ByteArkPlayerSubtitleSize

Small subtitle size (5% of video height)

medium → const ByteArkPlayerSubtitleSize

Medium subtitle size (6% of video height)

large → const ByteArkPlayerSubtitleSize

Large subtitle size (7% of video height)

extraLarge → const ByteArkPlayerSubtitleSize

Extra large subtitle size (8% of video height)

maximum → const ByteArkPlayerSubtitleSize

Maximum subtitle size (9% of video height)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ByteArkPlayerSubtitleSize>
A constant List of the values in this enum, in order of their declaration.