onAdsFirstQuartile property
Called when the first quartile of the ad is reached.
Implementation
final Function(ByteArkPlayerAdsData data)? onAdsFirstQuartile;
Called when the first quartile of the ad is reached.
final Function(ByteArkPlayerAdsData data)? onAdsFirstQuartile;