onAdsThirdQuartile property
Called when the third quartile of the ad is reached.
Implementation
final Function(ByteArkPlayerAdsData data)? onAdsThirdQuartile;
Called when the third quartile of the ad is reached.
final Function(ByteArkPlayerAdsData data)? onAdsThirdQuartile;