NoCompatibleSourceException class

Thrown when no ByteArkPlayerSource in a Player Item's sources list is playable on the current platform.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable explanation naming the missing key system.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited