rawSubscribedEventNames constant
The exact set of raw JS event names the web backend should subscribe to
via player.on(...). Excludes the fullscreenchange:* virtual names
— the backend subscribes to fullscreenchange once and translates each
fire into the appropriate virtual based on player state.
Implementation
static const List<String> rawSubscribedEventNames = <String>[
'ready',
'loadstart',
'firstplay',
'play',
'pause',
'seeking',
'seeked',
'ended',
'timeupdate',
'waiting',
'canplay',
'error',
'fullscreenchange',
'enterpictureinpicture',
'leavepictureinpicture',
'resolutionchange',
'playlistitem',
'volumechange',
'audiotrackchange',
'texttrackchange',
'ads-request',
'ads-pod-started',
'ads-pod-ended',
'ads-ad-started',
'ads-ad-ended',
'ads-allpods-completed',
'ads-first-quartile',
'ads-midpoint',
'ads-third-quartile',
'ads-impression',
'ads-click',
'adserror',
'ads-ad-skipped',
];