requiresShakaPlugin static method

bool requiresShakaPlugin(
  1. List<ByteArkPlayerSource> sources
)

Whether the JS plugins.bytearkShaka plugin needs to be enabled for the given sources. Returns true iff at least one source carries DRM credentials.

Implementation

static bool requiresShakaPlugin(List<ByteArkPlayerSource> sources) {
  return sources.any((s) => s.drm != null);
}