ByteArkPlayerLighthouseMetaData class
Metadata for ByteArk Player Lighthouse tracking.
Constructors
- ByteArkPlayerLighthouseMetaData({String? userId, String? age, String? country, String? city, String? lat, String? long, String? gender, String? nationality, String? subscriptionPlan, String? accountCreationDate, String? videoTitle, String? seriesId, String? seriesTitle, String? season, String? episode, String? subEpisode, String? duration, String? publishedDate, String? genres, String? rating, String? d1, String? d2, String? d3, String? d4, String? d5, String? d6, String? d7, String? d8, String? d9, String? d10})
-
Creates a ByteArkPlayerLighthouseMetaData instance with optional parameters.
const
-
ByteArkPlayerLighthouseMetaData.fromMap(Map<
String, dynamic> map) -
Creates an instance from a key-value map.
factory
Properties
- accountCreationDate → String?
-
Date when the user's account was created.
final
- age → String?
-
User's age.
final
- city → String?
-
City or province of the user.
final
- country → String?
-
Country of the user.
final
- d1 → String?
-
Custom metadata field 1.
final
- d10 → String?
-
Custom metadata field 10.
final
- d2 → String?
-
Custom metadata field 2.
final
- d3 → String?
-
Custom metadata field 3.
final
- d4 → String?
-
Custom metadata field 4.
final
- d5 → String?
-
Custom metadata field 5.
final
- d6 → String?
-
Custom metadata field 6.
final
- d7 → String?
-
Custom metadata field 7.
final
- d8 → String?
-
Custom metadata field 8.
final
- d9 → String?
-
Custom metadata field 9.
final
- duration → String?
-
Duration of the video.
final
- episode → String?
-
Episode number of the video.
final
- gender → String?
-
Gender of the user.
final
- genres → String?
-
Genres of the video (comma-separated if multiple).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lat → String?
-
Latitude of the user.
final
- long → String?
-
Longitude of the user.
final
- nationality → String?
-
Nationality of the user.
final
- publishedDate → String?
-
Published date of the video.
final
- rating → String?
-
Rating of the video (e.g., PG-13).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- season → String?
-
Season of the series.
final
- seriesId → String?
-
Series ID the video belongs to.
final
- seriesTitle → String?
-
Title of the series the video belongs to.
final
- subEpisode → String?
-
Sub-episode identifier (if any).
final
- subscriptionPlan → String?
-
Subscription plan the user is on.
final
- userId → String?
-
User's unique identifier.
final
- videoTitle → String?
-
Title of the video.
final
Methods
-
copyWith(
{String? userId, String? age, String? country, String? city, String? lat, String? long, String? gender, String? nationality, String? subscriptionPlan, String? accountCreationDate, String? videoTitle, String? seriesId, String? seriesTitle, String? season, String? episode, String? subEpisode, String? duration, String? publishedDate, String? genres, String? rating, String? d1, String? d2, String? d3, String? d4, String? d5, String? d6, String? d7, String? d8, String? d9, String? d10}) → ByteArkPlayerLighthouseMetaData - Creates a copy of this ByteArkPlayerLighthouseMetaData with the given fields replaced with the new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this metadata into a key-value map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited