NoCompatibleSourceException class
Thrown when no ByteArkPlayerSource in a Player Item's sources list is playable on the current platform.
- Implemented types
Constructors
- NoCompatibleSourceException(String message)
- Creates a NoCompatibleSourceException.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited